/*
    *
    * This file is a part of CoreStuff.
    * An activity viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#include <QDebug>
#include <QTime>

#include "pagereminders.h"
#include "ui_pagereminders.h"


pagereminders::pagereminders(QWidget *parent) :QWidget(parent),ui(new Ui::pagereminders)
{
    ui->setupUi(this);

    loadSettings();
    startSetup();
    setupRemindersView();
}

pagereminders::~pagereminders()
{
    delete ui;
}

void pagereminders::reload()
{
    setupRemindersView();
}

/**
 * @brief Loads application settings
 */
void pagereminders::loadSettings()
{
    listViewIconSize = sm->value("CoreApps", "ListViewIconSize");
}

void pagereminders::startSetup()
{
    ui->remindersView->setIconSize( listViewIconSize );
}

void pagereminders::setupRemindersView()
{
    ui->remindersView->clear();

    QSettings *settings = new QSettings("coreapps", "alarm");
    int count = settings->value("AlarmCount").toInt();

    // Follows coretime weekday enum index
    QStringList weeks = {"Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"};

    for (int i = 0; i < count; i++) {
        QString alarmId(QString("Alarm%1").arg(i));
        settings->beginGroup(alarmId);

        QString repeat = "";

        bool repeatB = settings->value("Repeat").toBool();
        if (repeatB) {
            settings->beginGroup("Weekdays");
            int count = 0;
            QString sep = "/";
            for (int j = 0; j < 7; j++) {
                if (settings->value(QString("%1").arg(j + 1)).toBool()) {
                    count++;
                    if (j == 6) {
                        sep = "";
                    }
                    repeat += weeks[j] + sep;
                }
            }
            settings->endGroup();

            if (count == 7) {
                repeat = "Everyday";
            }
        } else {
            repeat = "Not Repeated";
        }
        QString str = settings->value("StartTime").toTime().toString("hh:mm AP") + "\t" +
                      (settings->value("AlarmEnable").toBool() ? "Enabled" : "Disabled") + "\t" +
                      repeat + "\t" +
                      settings->value("ReminderText").toString();
        settings->endGroup();

        QListWidgetItem *item = new QListWidgetItem(str);
        item->setIcon(QIcon(":/icons/alarm.svg"));
        ui->remindersView->addItem(item);
    }
}
