/*
    *
    * This file is a part of CoreStuff.
    * An activity viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/


#include <QDebug>

#include "client_c.h"
#include "x11support.h"


ClientT::ClientT(unsigned long handle)
{
    m_handle = handle;

    XSelectInput(QX11Info::display(), m_handle, PropertyChangeMask | StructureNotifyMask);

    updateVisibility();
    updateName();
    updateIcon();
    updateUrgency();
}

ClientT::~ClientT()
{
}

void ClientT::windowPropertyChanged(unsigned long atom)
{
    if (atom == X11Support::atom("_NET_WM_WINDOW_TYPE") || atom == X11Support::atom("_NET_WM_STATE")) {
        updateVisibility();
    }

    if (atom == X11Support::atom("_NET_WM_VISIBLE_NAME") || atom == X11Support::atom("_NET_WM_NAME") || atom == X11Support::atom("WM_NAME")) {
        updateName();
    }

    if (atom == X11Support::atom("_NET_WM_ICON")) {
        updateIcon();
    }

    if (atom == X11Support::atom("WM_HINTS")) {
        updateUrgency();
    }
}

void ClientT::updateVisibility()
{
    QVector<unsigned long> windowTypes = X11Support::getWindowPropertyAtomsArray(m_handle, "_NET_WM_WINDOW_TYPE");
    QVector<unsigned long> windowStates = X11Support::getWindowPropertyAtomsArray(m_handle, "_NET_WM_STATE");

    // Show only regular windows in dock.
    // When no window type is set, assume it's normal window.
    m_visible = (windowTypes.size() == 0) || (windowTypes.size() == 1 && windowTypes[0] == X11Support::atom("_NET_WM_WINDOW_TYPE_NORMAL"));

    // Don't show window if requested explicitly in window states.
    if (windowStates.contains(X11Support::atom("_NET_WM_STATE_SKIP_TASKBAR"))) {
        m_visible = false;
    } else {
        m_visible = true;
    }
}

void ClientT::updateName()
{
    m_name = X11Support::getWindowName(m_handle);
}

void ClientT::updateIcon()
{
    m_icon = X11Support::getWindowIcon(m_handle);
}

void ClientT::updateUrgency()
{
    m_isUrgent = X11Support::getWindowUrgency(m_handle);
}
