/*
    *
    * This file is a part of CoreStuff.
    * An activity viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/

#pragma once


#include <QWidget>
#include <QListWidgetItem>

#include "fixx11h.h"
#include "global.h"
#include "client_c.h"
#include "cxcbeventfilter.h"
#include "x11support.h"

class corestuff;

namespace Ui {
	class pagetasks;
}

class pagetasks : public QWidget {
    Q_OBJECT

public:
    explicit pagetasks(QWidget *parent = nullptr);
    ~pagetasks();

    void setCoreStuff(corestuff *cstuff) {
        m_cstuff = cstuff;
    }

    CXCBEventFilter cXCV;

private slots:
    void windowPropertyChanged(unsigned long window, unsigned long atom);
    void windowReconfigured(unsigned long window, int x, int y, int width, int height);
    void closeActiveApp();

private:
    Ui::pagetasks   *ui;
    QSize            listViewIconSize;
    bool             touch;
    unsigned long    m_activeWindow;
    X11Support      *m_x11support;
    QList <ClientT *> m_in_loop;
    QMap<unsigned long, ClientT *> m_clients;

    corestuff *m_cstuff = nullptr;

    void loadSettings();
    void startSetup();
    void setupTaskView();
    void updateActiveWindow();
    void setFocusApp(QListWidgetItem *item);
    void updateClientList();
};
